@@ -4,7 +4,7 @@ from holoviews import Curve
 from holoviews.plotting import bokeh
 
 from utilities._holoviews.common import apply_opts
-from utilities.errors import redirect_context
+from utilities.errors import redirect_error
 from utilities.numpy import has_dtype
 from utilities.text import EnsureStrError, ensure_str
 from utilities.xarray import DataArrayB1, DataArrayF1, DataArrayI1
@@ -24,7 +24,7 @@ def plot_curve(
     if has_dtype(array, bool):
         return plot_curve(array.astype(int), label=label, smooth=smooth, aspect=aspect)
     (kdim,) = array.dims
-    with redirect_context(EnsureStrError, PlotCurveError(f"{array.name=}")):
+    with redirect_error(EnsureStrError, PlotCurveError(f"{array.name=}")):
         vdim = ensure_str(array.name)
     if len(vdim) == 0:
         msg = f"{array.name=}"
