@@ -1,24 +1,23 @@
-from enum import unique
+from __future__ import annotations
+
+from enum import Enum, unique
 from logging import basicConfig
 
-from beartype import beartype
-
-from utilities.enum import StrEnum
+from utilities.datetime import maybe_sub_pct_y
 
 
-@beartype
 def basic_config() -> None:
     """Do the basic config."""
     basicConfig(
         format="{asctime} | {name} | {levelname:8} | {message}",
-        datefmt="%4Y-%m-%d %H:%M:%S",
+        datefmt=maybe_sub_pct_y("%Y-%m-%d %H:%M:%S"),
         style="{",
         level=LogLevel.DEBUG.name,
     )
 
 
 @unique
-class LogLevel(StrEnum):
+class LogLevel(str, Enum):
     """An enumeration of the logging levels."""
 
     DEBUG = "DEBUG"
@@ -26,3 +25,6 @@ class LogLevel(StrEnum):
     WARNING = "WARNING"
     ERROR = "ERROR"
     CRITICAL = "CRITICAL"
+
+
+__all__ = ["LogLevel", "basic_config"]
